@@ -189,10 +189,6 @@ from ncbi.datasets.openapi.model.v1_tabular_output import V1TabularOutput
 from ncbi.datasets.openapi.model.v1_tabular_output import V1TabularOutput as V1alpha1TabularOutput
 from ncbi.datasets.openapi.model.v1_tax_tree_request import V1TaxTreeRequest
 from ncbi.datasets.openapi.model.v1_tax_tree_request import V1TaxTreeRequest as V1alpha1TaxTreeRequest
-from ncbi.datasets.openapi.model.v1_taxid_reply import V1TaxidReply
-from ncbi.datasets.openapi.model.v1_taxid_reply import V1TaxidReply as V1alpha1TaxidReply
-from ncbi.datasets.openapi.model.v1_taxid_request import V1TaxidRequest
-from ncbi.datasets.openapi.model.v1_taxid_request import V1TaxidRequest as V1alpha1TaxidRequest
 from ncbi.datasets.openapi.model.v1_taxonomy_filtered_subtree_request import V1TaxonomyFilteredSubtreeRequest
 from ncbi.datasets.openapi.model.v1_taxonomy_filtered_subtree_request import V1TaxonomyFilteredSubtreeRequest as V1alpha1TaxonomyFilteredSubtreeRequest
 from ncbi.datasets.openapi.model.v1_taxonomy_filtered_subtree_response import V1TaxonomyFilteredSubtreeResponse
